@@ -6,13 +6,19 @@ package perl5i;
 ######################################
 
 use strict;
+use parent 'perl5i::latest';
+
 use perl5i::VERSION; our $VERSION = perl5i::VERSION->VERSION;
 
 my $Latest = perl5i::VERSION->latest;
 
 sub import {
-    require Carp;
-    Carp::croak(<<END);
+    if ($0 eq '-e') {
+        goto &perl5i::latest::import;
+    }
+    else {
+        require Carp;
+        Carp::croak(<<END);
 perl5i will break compatibility in the future, you can't just "use perl5i".
 
 Instead, "use $Latest" which will guarantee compatibility with all
@@ -20,6 +26,7 @@ features supplied in that major version.
 
 Type "perldoc perl5i" for details in the section "Using perl5i".
 END
+    }
 }
 
 1;
@@ -70,7 +77,8 @@ Thus the code you write with, for example, C<perl5i::2> will always
 remain compatible even as perl5i moves on.
 
 If you want to be daring, you can C<use perl5i::latest> to get the
-latest version.
+latest version. This will automatically happen if the program is C<-e>.
+This lets you do slightly less typing for one-liners like C<perl -Mperl5i -e ...>
 
 If you want your module to depend on perl5i, you should depend on the
 versioned class.  For example, depend on C<perl5i::2> and not
@@ -239,7 +247,7 @@ functionality without polluting the global namespace.
 L<autobox::Core> wraps a lot of Perl's built in functions so they can
 be called as methods on unblessed variables.  C<< @a->pop >> for example.
 
-=head3 alias()
+=head3 alias
 
     $scalar_reference->alias( @identifiers );
     @alias->alias( @identifiers );
@@ -294,9 +302,11 @@ This is basically a nicer way to say:
 
 =head2 Scalar Autoboxing
 
-perl5i adds some methods to scalars of its own.
+All of the methods provided by L<autobox::Core> are available from perl5i.
 
-=head3 center()
+in addition, perl5i adds some methods of its own.
+
+=head3 center
 
     my $centered_string = $string->center($length);
     my $centered_string = $string->center($length, $character);
@@ -428,7 +438,7 @@ immediately call $module's C<import> method to emulate a C<use>.
     # like "use $module;" if that worked
     $module->require->import;
 
-=head3 wrap()
+=head3 wrap
 
     my $wrapped = $string->wrap( width => $cols, separator => $sep );
 
@@ -440,11 +450,11 @@ the newline character "\n".
 
 See L<Text::Wrap> for details.
 
-=head3 ltrim()
+=head3 ltrim
 
-=head3 rtrim()
+=head3 rtrim
 
-=head3 trim()
+=head3 trim
 
     my $trimmed = $string->trim;
     my $trimmed = $string->trim($character_set);
@@ -464,14 +474,14 @@ whitespace.
     my $string = '-> test <-'->trim('-><');  # ' test '   
 
 
-=head3 title_case()
+=head3 title_case
 
     my $name = 'joe smith'->title_case;   # Joe Smith
 
 Will uppercase every word character that follows a wordbreak character.
 
 
-=head3 path2module()
+=head3 path2module
 
     my $module = $path->path2module;
 
@@ -483,7 +493,7 @@ For example,
 It will throw an exception if given something which could not be a
 path to a Perl module.
 
-=head3 module2path()
+=head3 module2path
 
     my $path = $module->module2path;
 
@@ -493,6 +503,16 @@ For example,
     "Foo::Bar"->module2path;  # "Foo/Bar.pm"
 
 
+=head3 is_module_name
+
+    my $is_valid = $string->is_module_name;
+
+Will return true if the $string is a valid module name.
+
+    "Foo::Bar"->is_module_name;  # true
+    "Foo/Bar"->is_module_name;   # false
+
+
 =head3 group_digits
 
     my $number_grouped     = $number->group_digits;
@@ -501,7 +521,7 @@ For example,
 Turns a number like 1234567 into a string like 1,234,567 known as "digit grouping".
 
 It honors your current locale to determine the separator and grouping.
-This can be overriden using C<%options>.
+This can be overridden using C<%options>.
 
 NOTE: many systems do not have their numeric locales set properly
 
@@ -547,26 +567,37 @@ is useful when you want a predictable result regardless of the user's
 locale settings.
 
 C<%options> defaults to C<< ( separator => ",", grouping => 3, decimal_point => "." ) >>.
-Each key will be overriden individually.
+Each key will be overridden individually.
 
     1234->commify;                      # 1,234
     1234->commify({ separator => "." });  # 1.234
 
 
-=head2 List Autoboxing
+=head3 reverse
+
+    my $reverse = $string->reverse;
+
+Reverses a $string.
+
+Unlike Perl's reverse(), this always reverses the string regardless of context.
+
+
+=head2 Array Autoboxing
+
+The methods provided by L<autobox::Core/Array Methods> are available
+from perl5i.
 
 All the functions from L<List::Util> and select ones from
-L<List::MoreUtils> are all available as methods on unblessed arrays and array refs.
+L<List::MoreUtils> are all available as methods on unblessed arrays
+and array refs: first, max, maxstr, min, minstr, minmax, shuffle,
+reduce, sum, any, all, none, true, false, uniq and mesh.
 
-first, max, maxstr, min, minstr, minmax, shuffle, reduce, sum, any,
-all, none, true, false, uniq and mesh.
-
-The have all been altered to return array refs where applicable in
+They have all been altered to return array refs where applicable in
 order to allow chaining.
 
     @array->grep(sub{ $_->is_number })->sum->say;
 
-=head3 foreach()
+=head3 foreach
 
     @array->foreach( func($item) { ... } );
 
@@ -590,7 +621,7 @@ If @array is not a multiple of the iteration (for example, @array has
 5 elements and you ask 2 at a time) the behavior is currently undefined.
 
 
-=head3 diff()
+=head3 diff
 
 Calculate the difference between two (or more) arrays:
 
@@ -629,7 +660,7 @@ L<Path::Class>, etc.), it tries its best to treat them as strings or numbers.
     [ $uri ]->diff( [ $uri2 ] );                 # empty, they are equal
 
 
-=head3 intersect()
+=head3 intersect
 
     my @a = (1 .. 10);
     my @b = (5 .. 15);
@@ -643,11 +674,11 @@ As with C<diff()>, it works with any number of arrays, nested data
 structures of arbitrary depth, and handles overloaded objects
 graciously.
 
-=head3 ltrim()
+=head3 ltrim
 
-=head3 rtrim()
+=head3 rtrim
 
-=head3 trim()
+=head3 trim
 
     my @trimmed = @list->trim;
     my @trimmed = @list->trim($character_set);
@@ -667,7 +698,24 @@ which will determine what characters should be trimmed.
 
 =head2 Hash Autoboxing
 
-=head3 flip()
+All of the methods provided by L<autobox::Core/Hash Methods> are
+available from perl5i.
+
+In addition...
+
+=head3 each
+
+Iterate through each key/value pair in a hash using a callback.
+
+    my %things = ( foo => 23, bar => 42 );
+    %things->each( func($k, $v) {
+        say "Key: $k, Value: $v"
+    });
+
+Unlike the C<each> function, individual calls to each are guaranteed
+to iterate through the entirety of the hash.
+
+=head3 flip
 
 Exchanges values for keys in a hash.
 
@@ -687,7 +735,7 @@ nested hashes.
     { foo => [ 'bar', 'baz' ] }->flip; # dies
 
 
-=head3 merge()
+=head3 merge
 
 Recursively merge two or more hashes together using L<Hash::Merge::Simple>.
 
@@ -708,7 +756,7 @@ It also works with nested hashes, although it won't attempt to merge
 array references or objects. For more information, look at the
 L<Hash::Merge::Simple> docs.
 
-=head3 diff()
+=head3 diff
 
     my %staff    = ( bob => 42, martha => 35, timmy => 23 );
     my %promoted = ( timmy => 23 );
@@ -719,13 +767,14 @@ Returns the key/value pairs present in the first hash that are not
 present in the subsequent hash arguments.  Otherwise works as
 C<< @array->diff >>.
 
-=head3 intersect()
+=head3 intersect
 
     %staff->intersect(\%promoted); # { timmy => 23 }
 
 Returns the key/value pairs that are present simultaneously in all the
 hash arguments.  Otherwise works as C<< @array->intersect >>.
 
+
 =head2 Code autoboxing
 
 =head3 signature
@@ -740,26 +789,41 @@ signature.  See L<perl5i::Signature> for details.  Otherwise it
 returns nothing.
 
 
-=head2 caller()
+=head2 caller
 
 L<Perl6::Caller> causes C<caller> to return an object in scalar
 context.
 
-=head2 die()
+=head2 die
 
 C<die> now always returns an exit code of 255 instead of trying to use
 C<$!> or C<$?> which makes the exit code unpredictable.  If you want
 to exit with a message and a special exit code, use C<warn> then
 C<exit>.
 
-=head2 utf8
+=head2 list
 
-L<utf8> lets you put UTF8 encoded strings into your source code.
-This means UTF8 variable and method names, strings and regexes.
+C<list> will force list context similar to how
+L<scalar|perlfunc/scalar> will force scalar context.
 
-It means strings will be treated as a set of characters rather than a
-set of bytes.  For example, C<length> will return the number of
-characters, not the number of bytes.
+
+=head2 utf8::all
+
+perl5i turns on L<utf8::all> which turns on all the Unicode features
+of Perl it can.
+
+Here is the current list, more may be turned on later.
+
+Bare strings in your source code are now UTF8.  This means UTF8
+variable and method names, strings and regexes.
+
+    my $message = "انا لا اتكلم العربيه";
+    my $τάδε    = "It's all Greek to me!";
+    sub fünkßhüñ { ... }
+
+Strings will be treated as a set of characters rather than a set of
+bytes.  For example, C<length> will return the number of characters,
+not the number of bytes.
 
     length("perl5i is MËTÁŁ");  # 15, not 18
 
@@ -769,7 +833,7 @@ STDOUT, STDIN, STDERR and all newly opened filehandles will have UTF8
 encoding turned on.  Consequently, if you want to output raw bytes to
 a file, such as outputting an image, you must set C<< binmode $fh >>.
 
-=head2 capture()
+=head2 capture
 
     my($stdout, $stderr) = capture { ... } %options;
     my $stdout = capture { ... } %options;
@@ -846,31 +910,8 @@ You can also request a pipe for IPC:
     my $message = $proc->read();
     $proc->say("reply");
 
-API Overview: (See L<Child> for more information)
+See L<Child> for more information.
 
-=over 4
-
-=item $proc->is_complete()
-
-=item $proc->wait()
-
-=item $proc->kill($SIG)
-
-=item $proc->pid()
-
-=item $proc->exit_status()
-
-=item $parent->pid()
-
-=item $parent->detach()
-
-=item $proc_or_parent->read()
-
-=item $proc_or_parent->write( @MESSAGES )
-
-=item $proc_or_parent->say( @MESSAGES )
-
-=back
 
 =head2 English
 
@@ -1023,6 +1064,10 @@ And you can use it on the C<#!> line.
 
     gmtime->year->say;
 
+If you write a one-liner without using this program, saying C<-Mperl5i> means
+C<-Mperl5i::latest>. Please see L</"Using perl5i"> and L</VERSIONING> for
+details.
+
 
 =head1 BUGS
 
